@@ -55,6 +55,12 @@
   MN_CONF_COMMANDS_NEW_MAIL_NAMESPACE "/enabled"
 #define MN_CONF_COMMANDS_NEW_MAIL_COMMAND \
   MN_CONF_COMMANDS_NEW_MAIL_NAMESPACE "/command"
+#define MN_CONF_COMMANDS_MAIL_READ_NAMESPACE \
+  MN_CONF_COMMANDS_NAMESPACE "/mail-read"
+#define MN_CONF_COMMANDS_MAIL_READ_ENABLED \
+  MN_CONF_COMMANDS_MAIL_READ_NAMESPACE "/enabled"
+#define MN_CONF_COMMANDS_MAIL_READ_COMMAND \
+  MN_CONF_COMMANDS_MAIL_READ_NAMESPACE "/command"
 #define MN_CONF_COMMANDS_CLICKED_NAMESPACE \
   MN_CONF_COMMANDS_NAMESPACE "/clicked"		/* obsolete */
 #define MN_CONF_COMMANDS_CLICKED_ENABLED \
